@@ -5,7 +5,7 @@ function(node)
     if(length(node) > 1 || node == "*")
         stop("node cannot be a vector, nor '*'")
     nodeName <- sQuote(node)
-    command <- paste("RanksEmbed.SetVariable(", nodeName, ") RanksEmbed.StatsGuard",
+    command <- paste("RanksEmbed.SetVariable(", nodeName, "); RanksEmbed.StatsGuard;",
                              "RanksEmbed.Stats")
     .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
     buffer <- file.path(tempdir(), "buffer.txt")
