@@ -4,7 +4,7 @@ function(node)
 {
     nodeName <- sQuote(node)
     for(i in seq(along=nodeName)){
-        command <- paste("SummaryEmbed.SetVariable(", nodeName[i], ") SummaryEmbed.StatsGuard",
+        command <- paste("SummaryEmbed.SetVariable(", nodeName[i], "); SummaryEmbed.StatsGuard;",
                          "SummaryEmbed.Clear")
         .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
         buffer <- file.path(tempdir(), "buffer.txt")
