@@ -6,7 +6,7 @@ function(node)
     result <- data.frame(mean=NULL, sd=NULL, val2.5pc=NULL, 
                          median=NULL, val97.5pc=NULL, sample=NULL)
     for(i in seq(along=nodeName)){
-        command <- paste("SummaryEmbed.SetVariable(", nodeName[i], ") SummaryEmbed.StatsGuard",
+        command <- paste("SummaryEmbed.SetVariable(", nodeName[i], "); SummaryEmbed.StatsGuard;",
                          "SummaryEmbed.Stats")
         .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
         buffer <- file.path(tempdir(), "buffer.txt")
